@@ -1,5 +1,6 @@
 import os
 import platform
+from time import sleep
 import subprocess
 def exist():
     sys = platform.system()
@@ -14,7 +15,8 @@ def install():
     sys = platform.system()
     if sys=="Darwin":
         subprocess.call(["/usr/bin/open",os.path.dirname(__file__)+"/driver/ch34x_install.pkg"])
-        #["installer","-pkg",os.path.dirname(__file__)+"/driver/ch34x_install.pkg","-target","/"])
     elif sys=="Windows":
         subprocess.call([os.path.dirname(__file__)+"/driver/ch34x_install.exe"])
+    while exist():
+        sleep(1)
     return
\ No newline at end of file
